Actions, Resources, and Condition Keys for AWS Support - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Support.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for AWS Support

AWS Support (service prefix: `support`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Support
- Resources Defined by AWS Support
- Condition Keys for AWS Support

## Actions Defined by AWS Support

AWS Support has no API operations that can be used in the `Actions` element of an IAM policy statement. To allow access to AWS Support, specify `“Action”: “support:*”` in your policy.

Note

Support does not let you allow or deny access to individual actions; therefore your policy must use the "Action": "support:*" to use the AWS Support Center or to use the Support API. In addition, when you use the Support API to call Trusted Advisor-related actions (such as DescribeTrustedAdvisorChecks), none of the "trustedadvisor:*" actions restrict your access. The "trustedadvisor:*" actions apply only to TrustedAdvisor in the Console.

## Resources Defined by AWS Support

AWS Support does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Support, specify `“Resource”: “*”` in your policy.

## Condition Keys for AWS Support

Support has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by AWS Support
- Resources Defined by AWS Support
- Condition Keys for AWS Support

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more